@@ -1,5 +1,4 @@
 import http
-from typing import Optional
 
 from fastapi import FastAPI, Path, Query
 
@@ -54,7 +53,7 @@ def get_bool_id(item_id: bool):
 
 
 @app.get("/path/param/{item_id}")
-def get_path_param_id(item_id: Optional[str] = Path()):
+def get_path_param_id(item_id: str | None = Path()):
     return item_id
 
 
@@ -161,7 +160,7 @@ def get_query_type(query: int):
 
 
 @app.get("/query/int/optional")
-def get_query_type_optional(query: Optional[int] = None):
+def get_query_type_optional(query: int | None = None):
     if query is None:
         return "foo bar"
     return f"foo bar {query}"
