@@ -1,4 +1,4 @@
-from typing import Annotated, Optional
+from typing import Annotated
 
 import pytest
 from fastapi import FastAPI, File, UploadFile
@@ -13,13 +13,13 @@ app = FastAPI()
 
 
 @app.post("/optional-list-bytes")
-async def read_optional_list_bytes(p: Annotated[Optional[list[bytes]], File()] = None):
+async def read_optional_list_bytes(p: Annotated[list[bytes] | None, File()] = None):
     return {"file_size": [len(file) for file in p] if p else None}
 
 
 @app.post("/optional-list-uploadfile")
 async def read_optional_list_uploadfile(
-    p: Annotated[Optional[list[UploadFile]], File()] = None,
+    p: Annotated[list[UploadFile] | None, File()] = None,
 ):
     return {"file_size": [file.size for file in p] if p else None}
 
@@ -41,7 +41,10 @@ def test_optional_list_schema(path: str):
                 "anyOf": [
                     {
                         "type": "array",
-                        "items": {"type": "string", "format": "binary"},
+                        "items": {
+                            "type": "string",
+                            "contentMediaType": "application/octet-stream",
+                        },
                     },
                     {"type": "null"},
                 ],
@@ -87,14 +90,14 @@ def test_optional_list(path: str):
 
 @app.post("/optional-list-bytes-alias")
 async def read_optional_list_bytes_alias(
-    p: Annotated[Optional[list[bytes]], File(alias="p_alias")] = None,
+    p: Annotated[list[bytes] | None, File(alias="p_alias")] = None,
 ):
     return {"file_size": [len(file) for file in p] if p else None}
 
 
 @app.post("/optional-list-uploadfile-alias")
 async def read_optional_list_uploadfile_alias(
-    p: Annotated[Optional[list[UploadFile]], File(alias="p_alias")] = None,
+    p: Annotated[list[UploadFile] | None, File(alias="p_alias")] = None,
 ):
     return {"file_size": [file.size for file in p] if p else None}
 
@@ -116,7 +119,10 @@ def test_optional_list_alias_schema(path: str):
                 "anyOf": [
                     {
                         "type": "array",
-                        "items": {"type": "string", "format": "binary"},
+                        "items": {
+                            "type": "string",
+                            "contentMediaType": "application/octet-stream",
+                        },
                     },
                     {"type": "null"},
                 ],
@@ -176,16 +182,14 @@ def test_optional_list_alias_by_alias(path: str):
 
 @app.post("/optional-list-bytes-validation-alias")
 def read_optional_list_bytes_validation_alias(
-    p: Annotated[Optional[list[bytes]], File(validation_alias="p_val_alias")] = None,
+    p: Annotated[list[bytes] | None, File(validation_alias="p_val_alias")] = None,
 ):
     return {"file_size": [len(file) for file in p] if p else None}
 
 
 @app.post("/optional-list-uploadfile-validation-alias")
 def read_optional_list_uploadfile_validation_alias(
-    p: Annotated[
-        Optional[list[UploadFile]], File(validation_alias="p_val_alias")
-    ] = None,
+    p: Annotated[list[UploadFile] | None, File(validation_alias="p_val_alias")] = None,
 ):
     return {"file_size": [file.size for file in p] if p else None}
 
@@ -207,7 +211,10 @@ def test_optional_validation_alias_schema(path: str):
                 "anyOf": [
                     {
                         "type": "array",
-                        "items": {"type": "string", "format": "binary"},
+                        "items": {
+                            "type": "string",
+                            "contentMediaType": "application/octet-stream",
+                        },
                     },
                     {"type": "null"},
                 ],
@@ -270,7 +277,7 @@ def test_optional_validation_alias_by_validation_alias(path: str):
 @app.post("/optional-list-bytes-alias-and-validation-alias")
 def read_optional_list_bytes_alias_and_validation_alias(
     p: Annotated[
-        Optional[list[bytes]], File(alias="p_alias", validation_alias="p_val_alias")
+        list[bytes] | None, File(alias="p_alias", validation_alias="p_val_alias")
     ] = None,
 ):
     return {"file_size": [len(file) for file in p] if p else None}
@@ -279,7 +286,7 @@ def read_optional_list_bytes_alias_and_validation_alias(
 @app.post("/optional-list-uploadfile-alias-and-validation-alias")
 def read_optional_list_uploadfile_alias_and_validation_alias(
     p: Annotated[
-        Optional[list[UploadFile]],
+        list[UploadFile] | None,
         File(alias="p_alias", validation_alias="p_val_alias"),
     ] = None,
 ):
@@ -303,7 +310,10 @@ def test_optional_list_alias_and_validation_alias_schema(path: str):
                 "anyOf": [
                     {
                         "type": "array",
-                        "items": {"type": "string", "format": "binary"},
+                        "items": {
+                            "type": "string",
+                            "contentMediaType": "application/octet-stream",
+                        },
                     },
                     {"type": "null"},
                 ],
