@@ -1,4 +1,4 @@
-from typing import Annotated, Optional
+from typing import Annotated
 
 import pytest
 from fastapi import FastAPI, Header
@@ -14,13 +14,13 @@ app = FastAPI()
 
 @app.get("/optional-list-str")
 async def read_optional_list_str(
-    p: Annotated[Optional[list[str]], Header()] = None,
+    p: Annotated[list[str] | None, Header()] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalListStr(BaseModel):
-    p: Optional[list[str]] = None
+    p: list[str] | None = None
 
 
 @app.get("/model-optional-list-str")
@@ -81,13 +81,13 @@ def test_optional_list_str(path: str):
 
 @app.get("/optional-list-alias")
 async def read_optional_list_alias(
-    p: Annotated[Optional[list[str]], Header(alias="p_alias")] = None,
+    p: Annotated[list[str] | None, Header(alias="p_alias")] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalListAlias(BaseModel):
-    p: Optional[list[str]] = Field(None, alias="p_alias")
+    p: list[str] | None = Field(None, alias="p_alias")
 
 
 @app.get("/model-optional-list-alias")
@@ -162,13 +162,13 @@ def test_optional_list_alias_by_alias(path: str):
 
 @app.get("/optional-list-validation-alias")
 def read_optional_list_validation_alias(
-    p: Annotated[Optional[list[str]], Header(validation_alias="p_val_alias")] = None,
+    p: Annotated[list[str] | None, Header(validation_alias="p_val_alias")] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalListValidationAlias(BaseModel):
-    p: Optional[list[str]] = Field(None, validation_alias="p_val_alias")
+    p: list[str] | None = Field(None, validation_alias="p_val_alias")
 
 
 @app.get("/model-optional-list-validation-alias")
@@ -246,16 +246,14 @@ def test_optional_list_validation_alias_by_validation_alias(path: str):
 @app.get("/optional-list-alias-and-validation-alias")
 def read_optional_list_alias_and_validation_alias(
     p: Annotated[
-        Optional[list[str]], Header(alias="p_alias", validation_alias="p_val_alias")
+        list[str] | None, Header(alias="p_alias", validation_alias="p_val_alias")
     ] = None,
 ):
     return {"p": p}
 
 
 class HeaderModelOptionalListAliasAndValidationAlias(BaseModel):
-    p: Optional[list[str]] = Field(
-        None, alias="p_alias", validation_alias="p_val_alias"
-    )
+    p: list[str] | None = Field(None, alias="p_alias", validation_alias="p_val_alias")
 
 
 @app.get("/model-optional-list-alias-and-validation-alias")
