@@ -1,6 +1,5 @@
 from collections.abc import AsyncGenerator
 from contextlib import asynccontextmanager
-from typing import Union
 
 import pytest
 from fastapi import APIRouter, FastAPI, Request
@@ -176,7 +175,7 @@ def test_router_nested_lifespan_state_overriding_by_parent() -> None:
     @asynccontextmanager
     async def lifespan(
         app: FastAPI,
-    ) -> AsyncGenerator[dict[str, Union[str, bool]], None]:
+    ) -> AsyncGenerator[dict[str, str | bool], None]:
         yield {
             "app_specific": True,
             "overridden": "app",
@@ -185,7 +184,7 @@ def test_router_nested_lifespan_state_overriding_by_parent() -> None:
     @asynccontextmanager
     async def router_lifespan(
         app: FastAPI,
-    ) -> AsyncGenerator[dict[str, Union[str, bool]], None]:
+    ) -> AsyncGenerator[dict[str, str | bool], None]:
         yield {
             "router_specific": True,
             "overridden": "router",  # should override parent
