@@ -1,5 +1,3 @@
-from typing import Optional
-
 from fastapi import FastAPI, Security
 from fastapi.security import OAuth2PasswordBearer
 from fastapi.testclient import TestClient
@@ -11,7 +9,7 @@ oauth2_scheme = OAuth2PasswordBearer(tokenUrl="/token", auto_error=False)
 
 
 @app.get("/items/")
-async def read_items(token: Optional[str] = Security(oauth2_scheme)):
+async def read_items(token: str | None = Security(oauth2_scheme)):
     if token is None:
         return {"msg": "Create an account first"}
     return {"token": token}
